# Pollination IO

A [Pollination](https://pollination.cloud) extension to facilitate working with Pollination SDK and apps.

## Installation

`python -m pip install -U pollination-io`

## Local Development
1. Clone this repo locally
```console
git clone git@github.com:pollination/pollination-io

# or

git clone https://github.com/pollination/pollination-io
```
2. Install dependencies:
```console
cd pollination-io
pip install -r dev-requirements.txt
pip install -r requirements.txt
```

3. Run Tests:
```console
python -m pytest tests/
```
